| Title: | Invasion Correction |
|---|---|
| Description: | The correction is achieved under the assumption that non-migrating cells of the essay approximately form a quadratic flow profile due to frictional effects, compare law of Hagen-Poiseuille for flow in a tube. The script fits a conical plane to give xyz-coordinates of the cells. It outputs the number of migrated cells and the new corrected coordinates. |
| Authors: | Marcus Rosenblatt |
| Maintainer: | Marcus Rosenblatt <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1 |
| Built: | 2026-05-26 09:48:35 UTC |
| Source: | https://github.com/cran/InvasionCorrection |
Correct z-component of a 3D collagen invasion essay. The correction is achieved under the assumption that non-migrating cells of the essay approximately form a quadratic flow profile due to frictional effects, compare law of Hagen-Poiseuille for flow in a tube.
correctByConicalPlane(filename, nrfits = 1000, threshold = -30, plot = FALSE, write_csv = TRUE)correctByConicalPlane(filename, nrfits = 1000, threshold = -30, plot = FALSE, write_csv = TRUE)
filename |
Name of data file in csv format. It should contain columns "Pos_X", "Pos_Y" and "Pos_Z". |
nrfits |
Numeric, Number of randomly chosen starting points for the optimization. Choose lower values for speeding up computational time. Choose higher values for more reliable optimization results. |
threshold |
Numeric, A threshold for counting cells as being invaded or not. When cells move towards negative z-direction, threshold should be negative. |
plot |
Boole, if TRUE exemplary 3D plots before and after the correction are plotted |
write_csv |
if TRUE resulting corrected values are saved as a csv file |
Data.frame containing input positions, corrected z-positions as well as number and percentage of invaded cells.
Marcus Rosenblatt, [email protected]